@@ -1,5 +1,5 @@
-""" Methods for PhotosDB to add Photos 5 photo score info 
-    ref: https://simonwillison.net/2020/May/21/dogsheep-photos/
+"""Methods for PhotosDB to add Photos 5 photo score info
+ref: https://simonwillison.net/2020/May/21/dogsheep-photos/
 """
 
 import logging
@@ -12,11 +12,11 @@ from .photosdb_utils import get_db_version
     This module should be imported in the class defintion of PhotosDB in photosdb.py
     Do not import this module directly
     This module adds the following method to PhotosDB:
-        _process_scoreinfo: process photo score info 
+        _process_scoreinfo: process photo score info
 
     The following data structures are added to PhotosDB
         self._db_scoreinfo_uuid
-    
+
     These methods only work on Photos 5 databases.  Will print warning on earlier library versions.
 """
 
@@ -50,41 +50,55 @@ def _process_scoreinfo_5(photosdb):
 
     (conn, cursor) = sqlite_open_ro(db)
 
-    result = cursor.execute(
-        f"""
-        SELECT 
-        {asset_table}.ZUUID,
-        {asset_table}.ZOVERALLAESTHETICSCORE,
-        {asset_table}.ZCURATIONSCORE,
-        {asset_table}.ZPROMOTIONSCORE,
-        {asset_table}.ZHIGHLIGHTVISIBILITYSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZBEHAVIORALSCORE, 
-        ZCOMPUTEDASSETATTRIBUTES.ZFAILURESCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZHARMONIOUSCOLORSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZIMMERSIVENESSSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZINTERACTIONSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZINTERESTINGSUBJECTSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZINTRUSIVEOBJECTPRESENCESCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZLIVELYCOLORSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZLOWLIGHT,
-        ZCOMPUTEDASSETATTRIBUTES.ZNOISESCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTCAMERATILTSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTCOMPOSITIONSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTLIGHTINGSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPATTERNSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPERSPECTIVESCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPOSTPROCESSINGSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTREFLECTIONSSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTSYMMETRYSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZSHARPLYFOCUSEDSUBJECTSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZTASTEFULLYBLURREDSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZWELLCHOSENSUBJECTSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZWELLFRAMEDSUBJECTSCORE,
-        ZCOMPUTEDASSETATTRIBUTES.ZWELLTIMEDSHOTSCORE
-        FROM {asset_table}
-        JOIN ZCOMPUTEDASSETATTRIBUTES ON ZCOMPUTEDASSETATTRIBUTES.ZASSET = {asset_table}.Z_PK
-        """
-    )
+    sql_query = f"""
+    SELECT
+    {asset_table}.ZUUID,
+    {asset_table}.ZOVERALLAESTHETICSCORE,
+    {asset_table}.ZCURATIONSCORE,
+    {asset_table}.ZPROMOTIONSCORE,
+    {asset_table}.ZHIGHLIGHTVISIBILITYSCORE,
+    """
+
+    if photosdb._photos_ver <= 10:
+        sql_query += "ZCOMPUTEDASSETATTRIBUTES.ZBEHAVIORALSCORE,\n"
+    else:
+        sql_query += "null,\n"
+
+    sql_query += """
+    ZCOMPUTEDASSETATTRIBUTES.ZFAILURESCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZHARMONIOUSCOLORSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZIMMERSIVENESSSCORE,
+    """
+
+    if photosdb._photos_ver <= 10:
+        sql_query += "ZCOMPUTEDASSETATTRIBUTES.ZINTERACTIONSCORE,"
+    else:
+        sql_query += "null,"
+
+    sql_query += f"""
+    ZCOMPUTEDASSETATTRIBUTES.ZINTERESTINGSUBJECTSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZINTRUSIVEOBJECTPRESENCESCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZLIVELYCOLORSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZLOWLIGHT,
+    ZCOMPUTEDASSETATTRIBUTES.ZNOISESCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTCAMERATILTSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTCOMPOSITIONSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTLIGHTINGSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPATTERNSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPERSPECTIVESCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTPOSTPROCESSINGSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTREFLECTIONSSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZPLEASANTSYMMETRYSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZSHARPLYFOCUSEDSUBJECTSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZTASTEFULLYBLURREDSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZWELLCHOSENSUBJECTSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZWELLFRAMEDSUBJECTSCORE,
+    ZCOMPUTEDASSETATTRIBUTES.ZWELLTIMEDSHOTSCORE
+    FROM {asset_table}
+    JOIN ZCOMPUTEDASSETATTRIBUTES ON ZCOMPUTEDASSETATTRIBUTES.ZASSET = {asset_table}.Z_PK
+    """
+
+    result = cursor.execute(sql_query)
 
     # 0     ZGENERICASSET.ZUUID,
     # 1     ZGENERICASSET.ZOVERALLAESTHETICSCORE,
